@@ -33,23 +33,7 @@
 #include <string.h>
 #include <math.h>
 
-#define EOG_THUMB_NAV_GET_PRIVATE(object) \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((object), EOG_TYPE_THUMB_NAV, EogThumbNavPrivate))
-
-G_DEFINE_TYPE (EogThumbNav, eog_thumb_nav, GTK_TYPE_BOX);
-
-#define EOG_THUMB_NAV_SCROLL_INC     20
-#define EOG_THUMB_NAV_SCROLL_MOVE    20
-#define EOG_THUMB_NAV_SCROLL_TIMEOUT 20
-
-enum
-{
-  PROP_SHOW_BUTTONS = 1,
-  PROP_THUMB_VIEW,
-  PROP_MODE
-};
-
-struct _EogThumbNavPrivate
+typedef struct
 {
   gboolean show_buttons;
   gboolean vertical;
@@ -67,17 +51,31 @@ struct _EogThumbNavPrivate
   GtkAdjustment *hadj;
   GtkAdjustment *vadj;
   GtkAdjustment *adj;
+} EogThumbNavPrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE (EogThumbNav, eog_thumb_nav, GTK_TYPE_BOX)
+
+#define EOG_THUMB_NAV_SCROLL_INC     20
+#define EOG_THUMB_NAV_SCROLL_MOVE    20
+#define EOG_THUMB_NAV_SCROLL_TIMEOUT 20
+
+enum
+{
+  PROP_SHOW_BUTTONS = 1,
+  PROP_THUMB_VIEW,
+  PROP_MODE
 };
 
 static gboolean
 eog_thumb_nav_scroll_event (GtkWidget *widget, GdkEventScroll *event, gpointer user_data)
 {
   EogThumbNav *nav = EOG_THUMB_NAV (user_data);
+  EogThumbNavPrivate *priv = eog_thumb_nav_get_instance_private (nav);
   gint         inc = EOG_THUMB_NAV_SCROLL_INC * 3;
   gdouble      value, upper, page_size, delta_x, delta_y;
   gboolean smooth;
 
-  nav->priv->adj = nav->priv->vertical ? nav->priv->vadj : nav->priv->hadj;
+  priv->adj =priv->vertical ? priv->vadj : priv->hadj;
 
   switch (event->direction)
   {
@@ -107,17 +105,17 @@ eog_thumb_nav_scroll_event (GtkWidget *widget, GdkEventScroll *event, gpointer u
       return FALSE;
   }
 
-  value = gtk_adjustment_get_value (nav->priv->adj);
+  value = gtk_adjustment_get_value (priv->adj);
   if (inc < 0)
-    gtk_adjustment_set_value (nav->priv->adj, MAX (0, value + inc));
+    gtk_adjustment_set_value (priv->adj, MAX (0, value + inc));
   else
   {
-    upper     = gtk_adjustment_get_upper (nav->priv->adj);
-    page_size = gtk_adjustment_get_page_size (nav->priv->adj);
-    gtk_adjustment_set_value (nav->priv->adj, MIN (upper - page_size, value + inc));
+    upper     = gtk_adjustment_get_upper (priv->adj);
+    page_size = gtk_adjustment_get_page_size (priv->adj);
+    gtk_adjustment_set_value (priv->adj, MIN (upper - page_size, value + inc));
   }
 
-  gtk_adjustment_value_changed (nav->priv->adj);
+  gtk_adjustment_value_changed (priv->adj);
 
   return TRUE;
 }
@@ -130,7 +128,7 @@ eog_thumb_nav_vadj_changed (GtkAdjustment *vadj, gpointer user_data)
   gdouble             value, upper, page_size;
 
   nav  = EOG_THUMB_NAV (user_data);
-  priv = EOG_THUMB_NAV_GET_PRIVATE (nav);
+  priv = eog_thumb_nav_get_instance_private (nav);
 
   g_object_get (vadj,
                 "value", &value,
@@ -152,7 +150,7 @@ eog_thumb_nav_hadj_changed (GtkAdjustment *hadj, gpointer user_data)
   gdouble             value, upper, page_size;
 
   nav  = EOG_THUMB_NAV (user_data);
-  priv = EOG_THUMB_NAV_GET_PRIVATE (nav);
+  priv = eog_thumb_nav_get_instance_private (nav);
   ltr  = gtk_widget_get_direction (priv->sw) == GTK_TEXT_DIR_LTR;
 
   g_object_get (hadj,
@@ -173,7 +171,7 @@ eog_thumb_nav_vadj_value_changed (GtkAdjustment *vadj, gpointer user_data)
   gdouble             value, upper, page_size;
 
   nav  = EOG_THUMB_NAV (user_data);
-  priv = EOG_THUMB_NAV_GET_PRIVATE (nav);
+  priv = eog_thumb_nav_get_instance_private (nav);
 
   g_object_get (vadj,
                 "value", &value,
@@ -196,7 +194,7 @@ eog_thumb_nav_hadj_value_changed (GtkAdjustment *hadj, gpointer user_data)
   gdouble             value, upper, page_size;
 
   nav  = EOG_THUMB_NAV (user_data);
-  priv = EOG_THUMB_NAV_GET_PRIVATE (nav);
+  priv = eog_thumb_nav_get_instance_private (nav);
   ltr  = gtk_widget_get_direction (priv->sw) == GTK_TEXT_DIR_LTR;
 
   g_object_get (hadj,
@@ -215,22 +213,23 @@ static gboolean
 eog_thumb_nav_scroll_step (gpointer user_data)
 {
   EogThumbNav *nav = EOG_THUMB_NAV (user_data);
+  EogThumbNavPrivate *priv = eog_thumb_nav_get_instance_private (nav);
   gint         delta;
   gdouble      value, upper, page_size;
 
-  if (nav->priv->scroll_pos < 10)
+  if (priv->scroll_pos < 10)
     delta = EOG_THUMB_NAV_SCROLL_INC;
-  else if (nav->priv->scroll_pos < 20)
+  else if (priv->scroll_pos < 20)
     delta = EOG_THUMB_NAV_SCROLL_INC * 2;
-  else if (nav->priv->scroll_pos < 30)
+  else if (priv->scroll_pos < 30)
     delta = EOG_THUMB_NAV_SCROLL_INC * 2 + 5;
   else
     delta = EOG_THUMB_NAV_SCROLL_INC * 2 + 12;
 
-  if (!nav->priv->scroll_dir)
+  if (!priv->scroll_dir)
     delta *= -1;
 
-  g_object_get (nav->priv->adj,
+  g_object_get (priv->adj,
                 "value", &value,
                 "upper", &upper,
                 "page_size", &page_size,
@@ -239,20 +238,20 @@ eog_thumb_nav_scroll_step (gpointer user_data)
   if ((gint) (value + (gdouble) delta) >= 0 &&
       (gint) (value + (gdouble) delta) <= upper - page_size)
   {
-    gtk_adjustment_set_value (nav->priv->adj, value + (gdouble) delta);
-    nav->priv->scroll_pos++;
-    gtk_adjustment_value_changed (nav->priv->adj);
+    gtk_adjustment_set_value (priv->adj, value + (gdouble) delta);
+    priv->scroll_pos++;
+    gtk_adjustment_value_changed (priv->adj);
   }
   else
   {
     if (delta > 0)
-      gtk_adjustment_set_value (nav->priv->adj, upper - page_size);
+      gtk_adjustment_set_value (priv->adj, upper - page_size);
     else
-      gtk_adjustment_set_value (nav->priv->adj, 0);
+      gtk_adjustment_set_value (priv->adj, 0);
 
-    nav->priv->scroll_pos = 0;
+    priv->scroll_pos = 0;
 
-    gtk_adjustment_value_changed (nav->priv->adj);
+    gtk_adjustment_value_changed (priv->adj);
 
     return G_SOURCE_REMOVE;
   }
@@ -263,22 +262,24 @@ eog_thumb_nav_scroll_step (gpointer user_data)
 static void
 eog_thumb_nav_button_clicked (GtkButton *button, EogThumbNav *nav)
 {
-  nav->priv->scroll_pos = 0;
+  EogThumbNavPrivate *priv = eog_thumb_nav_get_instance_private (nav);
 
-  if ((GTK_WIDGET (button) == nav->priv->button_right) ||
-      (GTK_WIDGET (button) == nav->priv->button_left))
+  priv->scroll_pos = 0;
+
+  if ((GTK_WIDGET (button) == priv->button_right) ||
+      (GTK_WIDGET (button) == priv->button_left))
   {
-    nav->priv->scroll_dir = gtk_widget_get_direction (GTK_WIDGET (button)) == GTK_TEXT_DIR_LTR ?
-                            GTK_WIDGET (button) == nav->priv->button_right :
-                            GTK_WIDGET (button) == nav->priv->button_left;
+    priv->scroll_dir = gtk_widget_get_direction (GTK_WIDGET (button)) == GTK_TEXT_DIR_LTR ?
+                       GTK_WIDGET (button) == priv->button_right :
+                       GTK_WIDGET (button) == priv->button_left;
   }
   else
   {
-    nav->priv->scroll_dir = (GTK_WIDGET (button) == nav->priv->button_down);
+    priv->scroll_dir = (GTK_WIDGET (button) == priv->button_down);
   }
 
-  nav->priv->adj = ((GTK_WIDGET (button) == nav->priv->button_right) ||
-                    (GTK_WIDGET (button) == nav->priv->button_left)) ? nav->priv->hadj : nav->priv->vadj;
+  priv->adj = ((GTK_WIDGET (button) == priv->button_right) ||
+               (GTK_WIDGET (button) == priv->button_left)) ? priv->hadj : priv->vadj;
 
   eog_thumb_nav_scroll_step (nav);
 }
@@ -286,34 +287,38 @@ eog_thumb_nav_button_clicked (GtkButton *button, EogThumbNav *nav)
 static void
 eog_thumb_nav_start_scroll (GtkButton *button, EogThumbNav *nav)
 {
-  if ((GTK_WIDGET (button) == nav->priv->button_right) ||
-      (GTK_WIDGET (button) == nav->priv->button_left))
+  EogThumbNavPrivate *priv = eog_thumb_nav_get_instance_private (nav);
+
+  if ((GTK_WIDGET (button) == priv->button_right) ||
+      (GTK_WIDGET (button) == priv->button_left))
   {
-    nav->priv->scroll_dir = gtk_widget_get_direction (GTK_WIDGET (button)) == GTK_TEXT_DIR_LTR ?
-                            GTK_WIDGET (button) == nav->priv->button_right :
-                            GTK_WIDGET (button) == nav->priv->button_left;
+    priv->scroll_dir = gtk_widget_get_direction (GTK_WIDGET (button)) == GTK_TEXT_DIR_LTR ?
+                       GTK_WIDGET (button) == priv->button_right :
+                       GTK_WIDGET (button) == priv->button_left;
   }
   else
   {
-    nav->priv->scroll_dir = (GTK_WIDGET (button) == nav->priv->button_down);
+    priv->scroll_dir = (GTK_WIDGET (button) == priv->button_down);
   }
 
-  nav->priv->adj = ((GTK_WIDGET (button) == nav->priv->button_right) ||
-                    (GTK_WIDGET (button) == nav->priv->button_left)) ? nav->priv->hadj : nav->priv->vadj;
+  priv->adj = ((GTK_WIDGET (button) == priv->button_right) ||
+               (GTK_WIDGET (button) == priv->button_left)) ? priv->hadj : priv->vadj;
 
-  nav->priv->scroll_id = g_timeout_add (EOG_THUMB_NAV_SCROLL_TIMEOUT,
-                                        eog_thumb_nav_scroll_step,
-                                        nav);
+  priv->scroll_id = g_timeout_add (EOG_THUMB_NAV_SCROLL_TIMEOUT,
+                                   eog_thumb_nav_scroll_step,
+                                   nav);
 }
 
 static void
 eog_thumb_nav_stop_scroll (GtkButton *button, EogThumbNav *nav)
 {
-  if (nav->priv->scroll_id > 0)
+  EogThumbNavPrivate *priv = eog_thumb_nav_get_instance_private (nav);
+
+  if (priv->scroll_id > 0)
   {
-    g_source_remove (nav->priv->scroll_id);
-    nav->priv->scroll_id  = 0;
-    nav->priv->scroll_pos = 0;
+    g_source_remove (priv->scroll_id);
+    priv->scroll_id  = 0;
+    priv->scroll_pos = 0;
   }
 }
 
@@ -324,6 +329,7 @@ eog_thumb_nav_get_property (GObject    *object,
                             GParamSpec *pspec)
 {
   EogThumbNav *nav = EOG_THUMB_NAV (object);
+  EogThumbNavPrivate *priv = eog_thumb_nav_get_instance_private (nav);
 
   switch (property_id)
   {
@@ -333,7 +339,7 @@ eog_thumb_nav_get_property (GObject    *object,
       break;
 
     case PROP_THUMB_VIEW:
-      g_value_set_object (value, nav->priv->thumbview);
+      g_value_set_object (value, priv->thumbview);
       break;
   }
 }
@@ -345,6 +351,7 @@ eog_thumb_nav_set_property (GObject      *object,
                             GParamSpec   *pspec)
 {
   EogThumbNav *nav = EOG_THUMB_NAV (object);
+  EogThumbNavPrivate *priv = eog_thumb_nav_get_instance_private (nav);
 
   switch (property_id)
   {
@@ -354,7 +361,7 @@ eog_thumb_nav_set_property (GObject      *object,
       break;
 
     case PROP_THUMB_VIEW:
-      nav->priv->thumbview =
+      priv->thumbview =
         GTK_WIDGET (g_value_get_object (value));
       break;
   }
@@ -371,7 +378,7 @@ eog_thumb_nav_constructor (GType                  type,
   object = G_OBJECT_CLASS (eog_thumb_nav_parent_class)->constructor
              (type, n_construct_properties, construct_params);
 
-  priv = EOG_THUMB_NAV_GET_PRIVATE (object);
+  priv = eog_thumb_nav_get_instance_private (EOG_THUMB_NAV (object));
 
   if (priv->thumbview != NULL)
   {
@@ -413,8 +420,6 @@ eog_thumb_nav_class_init (EogThumbNavClass *class)
                                                         G_PARAM_CONSTRUCT_ONLY |
                                                         G_PARAM_READWRITE |
                                                         G_PARAM_STATIC_STRINGS));
-
-  g_type_class_add_private (g_object_class, sizeof (EogThumbNavPrivate));
 }
 
 static void
@@ -423,9 +428,7 @@ eog_thumb_nav_init (EogThumbNav *nav)
   EogThumbNavPrivate *priv;
   GtkWidget          *arrow;
 
-  nav->priv = EOG_THUMB_NAV_GET_PRIVATE (nav);
-
-  priv = nav->priv;
+  priv = eog_thumb_nav_get_instance_private (nav);
 
   priv->show_buttons = TRUE;
   priv->vertical     = FALSE;
@@ -614,9 +617,11 @@ eog_thumb_nav_new (GtkWidget *thumbview,
 gboolean
 eog_thumb_nav_get_show_buttons (EogThumbNav *nav)
 {
+  EogThumbNavPrivate *priv;
+
   g_return_val_if_fail (EOG_IS_THUMB_NAV (nav), FALSE);
 
-  return nav->priv->show_buttons;
+  return priv->show_buttons;
 }
 
 /**
@@ -630,21 +635,26 @@ eog_thumb_nav_get_show_buttons (EogThumbNav *nav)
 void
 eog_thumb_nav_set_show_buttons (EogThumbNav *nav, gboolean show_buttons)
 {
-  g_return_if_fail (EOG_IS_THUMB_NAV (nav));
-  g_return_if_fail (nav->priv->button_left != NULL);
-  g_return_if_fail (nav->priv->button_right != NULL);
+  EogThumbNavPrivate *priv;
 
-  nav->priv->show_buttons = show_buttons;
+  g_return_if_fail (EOG_IS_THUMB_NAV (nav));
+
+  priv = eog_thumb_nav_get_instance_private (nav);
+
+  g_return_if_fail (priv->button_left != NULL);
+  g_return_if_fail (priv->button_right != NULL);
+
+  priv->show_buttons = show_buttons;
 
   if (show_buttons)
   {
-    gtk_widget_show_all (nav->priv->button_left);
-    gtk_widget_show_all (nav->priv->button_right);
+    gtk_widget_show_all (priv->button_left);
+    gtk_widget_show_all (priv->button_right);
   }
   else
   {
-    gtk_widget_hide (nav->priv->button_left);
-    gtk_widget_hide (nav->priv->button_right);
+    gtk_widget_hide (priv->button_left);
+    gtk_widget_hide (priv->button_right);
   }
 }
 
@@ -653,7 +663,7 @@ eog_thumb_nav_set_policy (EogThumbNav  *nav,
                           GtkPolicyType hscrollbar_policy,
                           GtkPolicyType vscrollbar_policy)
 {
-  EogThumbNavPrivate *priv = EOG_THUMB_NAV_GET_PRIVATE (nav);
+  EogThumbNavPrivate *priv = eog_thumb_nav_get_instance_private (nav);
 
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (priv->sw),
                                   hscrollbar_policy,
@@ -663,7 +673,7 @@ eog_thumb_nav_set_policy (EogThumbNav  *nav,
 gboolean
 eog_thumb_nav_is_vertical (EogThumbNav *nav)
 {
-  EogThumbNavPrivate *priv = EOG_THUMB_NAV_GET_PRIVATE (nav);
+  EogThumbNavPrivate *priv = eog_thumb_nav_get_instance_private (nav);
 
   return priv->vertical;
 }
@@ -671,9 +681,12 @@ eog_thumb_nav_is_vertical (EogThumbNav *nav)
 void
 eog_thumb_nav_set_vertical (EogThumbNav *nav, gboolean vertical)
 {
-  EogThumbNavPrivate *priv = EOG_THUMB_NAV_GET_PRIVATE (nav);
+  EogThumbNavPrivate *priv;
 
   g_return_if_fail (EOG_IS_THUMB_NAV (nav));
+
+  priv = eog_thumb_nav_get_instance_private (nav);
+
   g_return_if_fail (priv->button_left != NULL);
   g_return_if_fail (priv->button_right != NULL);
   g_return_if_fail (priv->vbox != NULL);
